[![Latest Github release](https://img.shields.io/github/release/nextgenusfs/gfftk.svg)](https://github.com/nextgenusfs/gfftk/releases/latest)
![Conda](https://img.shields.io/conda/dn/bioconda/gfftk)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

# GFFtk: genome annotation tool kit


To install release versions use the pip package manager, like so:
```
python -m pip install gfftk
```

To install the most updated code in master you can run:
```
python -m pip install git+https://github.com/nextgenusfs/gfftk.git
```
